==> eiffelstudio-18.11.10.2592.tar: F_code/C4/gb182.c <==
/*
 * Code for class GB_STANDARD_CMD
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb182.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_STANDARD_CMD}.make */
void F216_3700 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 215, Current, 0, 0, 3753);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {952,1464,0xFFF9,0,1390,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F953_9195(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("Default_command_name_Please_change_it",37,1434580852);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_8_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.execute_agents */
EIF_REFERENCE F216_3702 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


/* {GB_STANDARD_CMD}.pixmap */
EIF_REFERENCE F216_3703 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_13_);
}


/* {GB_STANDARD_CMD}.tooltip */
EIF_REFERENCE F216_3705 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_11_);
}


/* {GB_STANDARD_CMD}.description */
EIF_REFERENCE F216_3706 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_10_);
}


/* {GB_STANDARD_CMD}.menu_name */
EIF_REFERENCE F216_3707 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_9_);
}


/* {GB_STANDARD_CMD}.name */
EIF_REFERENCE F216_3708 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_8_);
}


/* {GB_STANDARD_CMD}.components */
EIF_REFERENCE F216_3709 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


/* {GB_STANDARD_CMD}.set_pixmaps */
void F216_3710 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_pixmaps", 215, Current, 0, 1, 3762);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_13_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {GB_STANDARD_CMD}.set_tooltip */
void F216_3711 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("set_tooltip", 215, Current, 0, 1, 3763);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_11_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_10_) == NULL)) {
		RTHOOK(3);
		RTAR(Current, arg1);
		*(EIF_REFERENCE *)(Current + _REFACS_10_) = (EIF_REFERENCE) arg1;
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.set_accelerator */
void F216_3713 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLIU(5);
	
	RTEAA("set_accelerator", 215, Current, 0, 1, 3765);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	tr1 = F1314_12021(RTCW(tr1));
	tb1 = F791_8929(RTCW(tr1));
	if (tb1) {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = F1314_12021(RTCW(tr1));
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1390,0,0xFFFF};
			EIF_TYPE typres0;
			typarr0[3] = dftype;
			
			typres0 = eif_compound_id(dftype, typarr0);
			tr2 = RTLNTS(typres0.id, 2, 0);
		}
		((EIF_TYPED_VALUE *)tr2+1)->it_r = Current;
		RTAR(tr2,Current);
		
		{
			static EIF_TYPE_INDEX typarr0[] = {1464,0xFFF9,0,1390,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr3 = RTLNRF(typres0.id, (EIF_POINTER) __A182_73, (EIF_POINTER) _A182_73, (EIF_POINTER)(F216_3719),tr2, 1, 0);
		}
		F1170_10956(RTCW(tr1), tr3);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.set_menu_name */
void F216_3714 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_menu_name", 215, Current, 0, 1, 3766);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_9_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {GB_STANDARD_CMD}.set_name */
void F216_3715 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_name", 215, Current, 0, 1, 3767);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_8_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {GB_STANDARD_CMD}.add_agent */
void F216_3716 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("add_agent", 215, Current, 0, 1, 3768);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7675[Dtype(tr1)-789])(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.execute */
void F216_3718 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("execute", 215, Current, 0, 0, 3770);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	F953_9214(RTCW(tr1));
	for (;;) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tb1 = *(EIF_BOOLEAN *)(RTCW(tr1) + O7852[Dtype(tr1)-952]);
		if (tb1) break;
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7688[Dtype(tr1)-789])(RTCW(tr1));
		(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_));
		;
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R7668[Dtype(tr1)-789])(RTCW(tr1));
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.execute_if_executable */
void F216_3719 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("execute_if_executable", 215, Current, 0, 0, 3771);
	RTGC;
	RTHOOK(1);
	if ((FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R3005[Dtype(Current)-159])(Current)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		F953_9214(RTCW(tr1));
		for (;;) {
			RTHOOK(3);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tb1 = *(EIF_BOOLEAN *)(RTCW(tr1) + O7852[Dtype(tr1)-952]);
			if (tb1) break;
			RTHOOK(4);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7688[Dtype(tr1)-789])(RTCW(tr1));
			(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_4_2_0_3_0_0_))(
				*(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_4_2_0_3_0_1_),
				*(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_));
			;
			RTHOOK(5);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R7668[Dtype(tr1)-789])(RTCW(tr1));
		}
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

void EIF_Minit182 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/gb182.c <==
/*
 * Code for class GB_STANDARD_CMD
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb182.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_STANDARD_CMD}.make */
void F216_3706 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 215, Current, 0, 0, 3762);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {954,1467,0xFFF9,0,1393,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F955_9215(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("Default_command_name_Please_change_it",37,1434580852);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_8_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.pixmap */
EIF_REFERENCE F216_3709 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_13_);
}


/* {GB_STANDARD_CMD}.tooltip */
EIF_REFERENCE F216_3711 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_11_);
}


/* {GB_STANDARD_CMD}.description */
EIF_REFERENCE F216_3712 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_10_);
}


/* {GB_STANDARD_CMD}.menu_name */
EIF_REFERENCE F216_3713 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_9_);
}


/* {GB_STANDARD_CMD}.name */
EIF_REFERENCE F216_3714 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_8_);
}


/* {GB_STANDARD_CMD}.components */
EIF_REFERENCE F216_3715 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


/* {GB_STANDARD_CMD}.set_pixmaps */
void F216_3716 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_pixmaps", 215, Current, 0, 1, 3771);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_13_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {GB_STANDARD_CMD}.set_tooltip */
void F216_3717 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("set_tooltip", 215, Current, 0, 1, 3772);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_11_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_10_) == NULL)) {
		RTHOOK(3);
		RTAR(Current, arg1);
		*(EIF_REFERENCE *)(Current + _REFACS_10_) = (EIF_REFERENCE) arg1;
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.set_accelerator */
void F216_3719 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLIU(5);
	
	RTEAA("set_accelerator", 215, Current, 0, 1, 3774);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	tr1 = F1317_12048(RTCW(tr1));
	tb1 = F793_8949(RTCW(tr1));
	if (tb1) {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current);
		tr1 = F1317_12048(RTCW(tr1));
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1393,0,0xFFFF};
			EIF_TYPE typres0;
			typarr0[3] = dftype;
			
			typres0 = eif_compound_id(dftype, typarr0);
			tr2 = RTLNTS(typres0.id, 2, 0);
		}
		((EIF_TYPED_VALUE *)tr2+1)->it_r = Current;
		RTAR(tr2,Current);
		
		{
			static EIF_TYPE_INDEX typarr0[] = {1467,0xFFF9,0,1393,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr3= RTLNRF(typres0.id, (EIF_POINTER) __A182_73, (EIF_POINTER) _A182_73, (EIF_POINTER)(F216_3725),tr2, 1, 0);
		}
		F1172_10981(RTCW(tr1), tr3);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.set_menu_name */
void F216_3720 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_menu_name", 215, Current, 0, 1, 3756);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_9_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {GB_STANDARD_CMD}.set_name */
void F216_3721 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_name", 215, Current, 0, 1, 3757);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_8_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {GB_STANDARD_CMD}.add_agent */
void F216_3722 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("add_agent", 215, Current, 0, 1, 3758);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7692[Dtype(RTCW(tr1))-844])(tr1, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.execute */
void F216_3724 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("execute", 215, Current, 0, 0, 3760);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	F955_9234(RTCW(tr1));
	for (;;) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tb1 = *(EIF_BOOLEAN *)(RTCW(tr1) + O7869[Dtype(tr1)-954]);
		if (tb1) break;
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7705[Dtype(RTCW(tr1))-844])(tr1);
		(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_));
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R7685[Dtype(RTCW(tr1))-954])(tr1);
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {GB_STANDARD_CMD}.execute_if_executable */
void F216_3725 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("execute_if_executable", 215, Current, 0, 0, 3761);
	RTGC;
	RTHOOK(1);
	if ((FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R2990[Dtype(Current)-216])(Current)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		F955_9234(RTCW(tr1));
		for (;;) {
			RTHOOK(3);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tb1 = *(EIF_BOOLEAN *)(RTCW(tr1) + O7869[Dtype(tr1)-954]);
			if (tb1) break;
			RTHOOK(4);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7705[Dtype(RTCW(tr1))-844])(tr1);
			(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_4_2_0_3_0_0_))(
				*(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_4_2_0_3_0_1_),
				*(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_));
			RTHOOK(5);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R7685[Dtype(RTCW(tr1))-954])(tr1);
		}
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

void EIF_Minit182 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
